@@ -1,26 +1,14 @@
-#ifndef REFLECTION_GRAPHICS_SCENE_H
-#define REFLECTION_GRAPHICS_SCENE_H
 /*
-   This file is part of the KDE games kwin4 program
-   Copyright (c) 2007 John Tapsel <tapsell@kde.org>
+    This file is part of the KDE games kwin4 program
+    SPDX-FileCopyrightText: 2007 John Tapsel <tapsell@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-// Qt includes
+#ifndef REFLECTION_GRAPHICS_SCENE_H
+#define REFLECTION_GRAPHICS_SCENE_H
+
+// Qt
 #include <QGraphicsPixmapItem>
 #include <QGraphicsScene>
 #include <QGraphicsTextItem>
